@@ -83,13 +83,13 @@ void MyImage::initFITS(fitsfile **fptr, QString loadFileName, int *status)
 {
     if (loadFileName.isNull() || loadFileName.isEmpty()) {
         *status = 1;
-        emit messageAvailable("MyImage::initFITS(): file name empty or not initialized!", "error");
+        emit messageAvailable(name+"MyImage::initFITS(): file name empty or not initialized!", "error");
         return;
     }
     // Bypassing a memory leak in cfitsio
     QFile file(loadFileName);
     if (!file.exists()) {
-        emit messageAvailable(name+" MyImage::initFITS(): file name empty or not initialized!", "error");
+        emit messageAvailable(name+" MyImage::initFITS(): File does not exist at current location!", "error");
         *status = 104;
         return;
     }
@@ -201,7 +201,8 @@ void MyImage::readDataWeight(fitsfile **fptr, int *status)
 
 bool MyImage::loadData(QString loadFileName)
 {
-    if (loadFileName.isEmpty()) loadFileName = path + "/" + chipName+processingStatus->statusString+".fits";
+    // pathExtension needed to load image when clicking on deactivated filename in memory table viewer
+    if (loadFileName.isEmpty()) loadFileName = path + "/" + pathExtension + "/" + chipName+processingStatus->statusString+".fits";
 
     int status = 0;
     fitsfile *fptr = nullptr;
@@ -257,7 +258,10 @@ bool MyImage::loadDataThreadSafe(QString loadFileName)
 // Setup the WCS
 void MyImage::initWCS()
 {
-    if (!successProcessing) return;
+    // CHECK: This line must be commented so that the redshift module works.
+    // For a reason I don't understand 'successProcessing' is wrong for the spectra when loaded.
+
+//    if (!successProcessing) return;
 
     emit setWCSLock(true);          // It appears that not everything in the wcslib is threadsafe
     int nreject;
