@@ -188,6 +188,8 @@ void MyImage::showProcInfo()
 
 void MyImage::checkCorrectMaskSize(const instrumentDataType *instData)
 {
+    if (instData->name.contains("DUMMY")) return;
+
     long n_mask = globalMask.length();
     long n_data = naxis1*naxis2;
     if (n_mask > 0 && n_mask != n_data) {
@@ -850,7 +852,8 @@ void MyImage::applyBackgroundModel(const MyImage *backgroundImage, QString mode,
             ++i;
         }
 
-        saturationValue /= backgroundImage->skyValue;
+        // No normalization of saturation keyword required
+//        saturationValue /= backgroundImage->skyValue;
         updateHeaderValue("SATURATE", saturationValue);
 
         QString img = " IMG = "+QString::number(skyValue, 'f', 3) + ";";
@@ -1564,15 +1567,25 @@ void MyImage::emitModelUpdateNeeded()
     emit modelUpdateNeeded(chipName);
 }
 
-// For use from within the memory viewer
+// For use from within the memory viewer; also called by the statistics module
 void MyImage::setActiveState(active_type state)
 {
     // Do nothing if the requested state equals the current state (otherwise, image might get deleted before moving it onto itself)
     if (activeState == state) return;
 
-    // Always us this function when setting the active status
+    // Always use this function when setting the active status
     activeState = state;
 
+    // If the file is currently inactive, check whether the processing state is the same as that of currently active images.
+    // Otherwise, the file must not be moved
+    if (state == MyImage::INACTIVE) {
+        if (processingStatus->statusString != processingStatus->whatIsStatusOnDrive()) {
+
+        }
+    }
+
+
+
     // Move the image accordingly
     QString currentPath = path + pathExtension;      // The path where the image is currently located (if on disk)
     updateInactivePath();                            // Update pathextension according to the set state
