@@ -239,6 +239,8 @@ public:
     double crval1 = 0.;
     double crval2 = 0.;
     double mjdobs = 0;
+    float geolon = 0.0;            // Earth coordinates
+    float geolat = 0.;             // Earth coordinates
     float fwhm = -1.0;             // FWHM estimate based on GAIA point sources
     float fwhm_est = -1.0;         // median FWHM of all detected sources in an image
     float RZP = 0;                 // SCAMP output
@@ -303,6 +305,14 @@ public:
     double alpha_ctr = 0.;   // Image center coords
     double delta_ctr = 0.;
 
+    // Transformations for binned mosaics
+    double tcd11 = 0.;
+    double tcd12 = 0.;
+    double tcd21 = 0.;
+    double tcd22 = 0.;
+    double tcrpix1 = 0.;
+    double tcrpix2 = 0.;
+
     // Associated data
     QVector<float> dataWeight;
     QVector<float> dataWeightSmooth;
@@ -310,6 +320,9 @@ public:
     //    QVector<uint> mask;
     float maskValue = 0.;
     float saturationValue = 1.e9;
+    float saturationValueL1 = 1.e9;
+    float saturationValueL2 = 1.e9;
+    float saturationValueL3 = 1.e9;
 
     bool allocatedImageFITS = false;
 
@@ -350,7 +363,7 @@ public:
     void buildAnetCommand(QString pixscale_maxerr);
     void buildSourceExtractorCommand();
     void calcMedianSeeingEllipticity();
-    void calcMedianSeeingEllipticitySex();
+    void calcMedianSeeingEllipticitySex(QString catName = "", int extnum = 0);
     void checkBrightStars(const QList<QVector<double> > &brightStarList, float safetyDistance, float plateScale);
     void checkCorrectMaskSize(const instrumentDataType *instData);
     void checkTaskRepeatStatus(QString taskBasename);
@@ -383,7 +396,7 @@ public:
     QString getKeyword(QString key);
     void getMJD();
     void getMeanBackground();
-    void getMode(bool determineMode = true);
+    void getMode(bool determineMode);
     double getPlateScale();
     void illuminationCorrection(int chip, QString thelidir, QString instName, QString filter);
     bool informSwarpfilter(long &naxis1, long &naxis2, double &crpix1, double &crpix2, double &sky, double &fluxscale);
@@ -470,7 +483,7 @@ public:
     void updateKeywordInHeader(QString key, QString value);
     void updateMode();
     void updateProcInfo(QString text);
-    void updateSaturation(QString saturation);
+    void updateHeaderSaturation();
     void updateZeroOrderOnDrive(QString updateMode);
     void writeBackgroundModel();
     void writeCatalog(QString minFWHM_string, QString maxFlag_string);
@@ -494,6 +507,7 @@ signals:
     void critical();
     void warning();
     void errorOccurred();
+    void WCSupdated();
 
 public slots:
     void messageAvailableReceived(QString message, QString type);
