@@ -185,6 +185,15 @@ void Splitter::WCSbuildCRPIX(int chip)
     // Exceptions. Return if successful.
     if (individualFixCRPIX(chip)) return;
 
+    if (chip >= instData.crpix1.length()) {
+        QString nfound = QString::number(chip+1);
+        QString nexpected = QString::number(instData.numChips);
+        emit messageAvailable(fileName + ": " + nfound + " detectors found, " + nexpected + " expected. Check instrument selection." , "error");
+        emit critical();
+        successProcessing = false;
+        return;
+    }
+
     QStringList headerWCS;
 
     // Use dedicated lookup
@@ -485,6 +494,14 @@ bool Splitter::individualFixCRPIX(int chip)
         individualFixDone = true;
     }
 
+    if (instData.name == "GMOS-S-HAM_4x4@GEMINI") {
+        if (chip == 3) crpix1_card = "CRPIX1  = 794";
+        if (chip == 7) crpix1_card = "CRPIX1  = 272";
+        if (chip == 11) crpix1_card = "CRPIX1  = -251";
+        crpix2_card = "CRPIX2  = 576";
+        individualFixDone = true;
+    }
+
     if (instData.name == "SOI@SOAR") {
         if (chip == 1) crpix1_card = "CRPIX1  = 1051";
         if (chip == 3) crpix1_card = "CRPIX1  = -26";
@@ -1105,6 +1122,10 @@ bool Splitter::individualFixGAIN(int chip)
         chipGain = 1.3;
         individualFixDone = true;
     }
+    if (instData.name == "INOLA@INO") {          // https://www.sbig.de/stf-8300/stf-8300-techdat.pdf
+        chipGain = 0.37;
+        individualFixDone = true;
+    }
     if (instData.name == "WHIRC@WIYN") {         // https://www.noao.edu/kpno/manuals/whirc/whirc.user.html
         chipGain = 3.4;
         individualFixDone = true;
@@ -1198,6 +1219,20 @@ bool Splitter::individualFixGAIN(int chip)
             }
         }
     }
+    else if (instData.name.contains("NOTcam")) {
+        float gain1 = 0.0;
+        float gain2 = 0.0;
+        float gain3 = 0.0;
+        float gain4 = 0.0;
+        searchKeyValue(QStringList() << "GAIN1", gain1);
+        searchKeyValue(QStringList() << "GAIN2", gain2);
+        searchKeyValue(QStringList() << "GAIN3", gain3);
+        searchKeyValue(QStringList() << "GAIN4", gain4);
+        channelGains.clear();
+        channelGains << gain1 << gain2 << gain3 << gain4;
+        chipGain = harmonicGain(channelGains);
+        individualFixDone = true;
+    }
 
     if (individualFixDone) {
         QString card1 = "GAINORIG= "+QString::number(chipGain, 'f', 6) + " / Original gain in the raw data for this image";
